==> gxargparse-0.2.1-py2.py3-none-any.whl: gxargparse/check_path.py <==
#!/usr/bin/env python
"""gxargparse_check_path checks for proper ordering of the system path

If gxargparse appears after python stdlib's argparse, it won't behave properly,
thus we provide a small check utility to ensure proper ordering and provide
suggestions if not functional.
"""
import sys, imp, os

def main(quiet=False):
    good_paths = []
    incorrect_ordering = False
    for path in sys.path:
      try:
        (handle, pathname, desc) = imp.find_module('argparse', [path])
        if desc[2] == 5:
            good_paths.append(pathname)
        elif len(good_paths) == 0:
            incorrect_ordering = True
      except:
          pass

    if incorrect_ordering:
        if len(good_paths) == 0:
            if not quiet:
                print "gxargparse not installed"
        else:
            if quiet:
                print "PYTHONPATH=%s " % os.path.dirname(good_paths[0])
            else:
                print "Incorrect ordering, please set\n\n\tPYTHONPATH=%s\n" % (os.path.dirname(good_paths[0]))
    else:
        if not quiet:
            print "Ready to go!"

if __name__ == '__main__':
    if len(sys.argv) == 1:
        main()
    else:
        if sys.argv[1] == '-h':
            print """Usage: gxargparse_check_path [-q] [-h]

Check the path for the correct setting to be able to take advantage
of gxargparse. The -q option prints quietly in order to allow for
things like

    user@host:$ $(gxargparse_check_path -q) python script.py
"""
            sys.exit(1)
        elif sys.argv[1] == '-q':
            main(quiet=True)
        else:
            print "Error, unknown flag. Usage: gxargparse_check_path [-q] [-h]"
            sys.exit(2)

==> gxargparse-0.2.2-py2.py3-none-any.whl: gxargparse/check_path.py <==
#!/usr/bin/env python
"""gxargparse_check_path checks for proper ordering of the system path

If gxargparse appears after python stdlib's argparse, it won't behave properly,
thus we provide a small check utility to ensure proper ordering and provide
suggestions if not functional.
"""
import sys, imp, os
import argparse

def get_args():
    help_text = """Check the path for the correct setting to be able to take advantage
of gxargparse.
"""
    parser = argparse.ArgumentParser(prog='gxargparse_check_path', description=help_text)
    parser.add_argument('-q', dest='quiet', action='store_true', help='run quietly')
    return parser.parse_args()

def main():
    args = get_args()

    good_paths = []
    incorrect_ordering = False
    for path in sys.path:
      try:
        (handle, pathname, desc) = imp.find_module('argparse', [path])
        if desc[2] == 5:
            good_paths.append(pathname)
        elif len(good_paths) == 0:
            incorrect_ordering = True
      except:
          pass

    if incorrect_ordering:
        if len(good_paths) == 0:
            if not args.quiet:
                print "gxargparse not installed"
        else:
            if args.quiet:
                print "PYTHONPATH=%s " % os.path.dirname(good_paths[0])
            else:
                print "Incorrect ordering, please set\n\n\tPYTHONPATH=%s\n" % (os.path.dirname(good_paths[0]))
    else:
        if not args.quiet:
            print "Ready to go!"

if __name__ == '__main__':
    main()
